@@ -1,17 +1,13 @@
-import os
 import json
+import os
 from datetime import date, datetime, time, timedelta
 from urllib.parse import urlparse
+from url_remote.environment_name_enum import EnvironmentName
 
-from .mini_logger import MiniLogger
+from dotenv import load_dotenv
 
-from .constants import (BRAND_NAME, ENVIRONMENT_NAME)  # noqa: E402
-
-from .validate_environment import (validate_brand_name,  # noqa: E402
-                                   validate_environment_name)
-
-
-RANGE_LENGTH = 2
+from .mini_logger import MiniLogger as logger
+load_dotenv()
 
 
 def timedelta_to_time_format(time_delta: timedelta) -> str:
@@ -31,10 +27,10 @@ def timedelta_to_time_format(time_delta: timedelta) -> str:
         >>> duration = timedelta(hours=2, minutes=30, seconds=45)
         >>> formatted_time = timedelta_to_time_format(duration)
         >>> print(formatted_time)
-        '02:30:45'
+        "02:30:45"
     """
     TIMEDELTA_TO_TIME_FORMAT_METHOD_NAME = "timedelta_to_time_format"
-    MiniLogger.start(TIMEDELTA_TO_TIME_FORMAT_METHOD_NAME, object={'time_delta': time_delta})
+    logger.start(TIMEDELTA_TO_TIME_FORMAT_METHOD_NAME, object={'time_delta': time_delta})
 
     # Calculate the total seconds and convert to HH:MM:SS format
     total_seconds = int(time_delta.total_seconds())
@@ -45,8 +41,8 @@ def timedelta_to_time_format(time_delta: timedelta) -> str:
     # Format as "HH:MM:SS"
     formatted_time = f"{hours:02d}:{minutes:02d}:{seconds:02d}"
 
-    MiniLogger.end(TIMEDELTA_TO_TIME_FORMAT_METHOD_NAME,
-                   object={'formatted_time': formatted_time})
+    logger.end(TIMEDELTA_TO_TIME_FORMAT_METHOD_NAME,
+               object={'formatted_time': formatted_time})
     return formatted_time
 
 
@@ -55,25 +51,25 @@ def is_valid_time_range(time_range: tuple) -> bool:
     Validate that the time range is in the format 'HH:MM:SS'.
     """
     IS_VALID_TIME_RANGE_METHOD_NAME = "is_valid_time_range"
-    MiniLogger.start(IS_VALID_TIME_RANGE_METHOD_NAME, object={
+    logger.start(IS_VALID_TIME_RANGE_METHOD_NAME, object={
         "time_range": time_range.__str__()})
-    if len(time_range) != RANGE_LENGTH:
-        MiniLogger.end(IS_VALID_TIME_RANGE_METHOD_NAME, object={
+    if len(time_range) != 2:
+        logger.end(IS_VALID_TIME_RANGE_METHOD_NAME, object={
             "is_valid_time_range_result": False, "reason": "len(time_range) != 2"})
         return False
 
     for time_obj in time_range:
         if not isinstance(time_obj, time):
-            MiniLogger.end(IS_VALID_TIME_RANGE_METHOD_NAME, object={
+            logger.end(IS_VALID_TIME_RANGE_METHOD_NAME, object={
                 "is_valid_time_range_result": False, "reason": "time_range contains non-time objects"})
             return False
         time_str = time_obj.strftime('%H:%M:%S')
         if time_obj.strftime('%H:%M:%S') != time_str:
-            MiniLogger.end(IS_VALID_TIME_RANGE_METHOD_NAME, object={
+            logger.end(IS_VALID_TIME_RANGE_METHOD_NAME, object={
                 "is_valid_time_range_result": False, "reason": "time_range contains invalid time format"})
             return False
 
-    MiniLogger.end(IS_VALID_TIME_RANGE_METHOD_NAME, object={
+    logger.end(IS_VALID_TIME_RANGE_METHOD_NAME, object={
         "is_valid_time_range_result": True})
     return True
 
@@ -90,19 +86,19 @@ def is_valid_date_range(date_range: tuple) -> bool:
     Validate that the date range is in the format 'YYYY-MM-DD'.
     """
     IS_VALID_DATE_RANGE_METHOD_NAME = "is_valid_date_range"
-    MiniLogger.start(IS_VALID_DATE_RANGE_METHOD_NAME, object={
+    logger.start(IS_VALID_DATE_RANGE_METHOD_NAME, object={
         "date_range": date_range.__str__()})
-    if len(date_range) != RANGE_LENGTH:
-        MiniLogger.end(IS_VALID_DATE_RANGE_METHOD_NAME, object={
+    if len(date_range) != 2:
+        logger.end(IS_VALID_DATE_RANGE_METHOD_NAME, object={
             "is_valid_date_range_result": False, "reason": "len(date_range) != 2"})
         return False
 
     for date_obj in date_range:
         if not isinstance(date_obj, date):
-            MiniLogger.end(IS_VALID_DATE_RANGE_METHOD_NAME, object={
+            logger.end(IS_VALID_DATE_RANGE_METHOD_NAME, object={
                 "is_valid_date_range_result": False, "reason": "date_range contains non-date objects"})
             return False
-    MiniLogger.end(IS_VALID_DATE_RANGE_METHOD_NAME, object={
+    logger.end(IS_VALID_DATE_RANGE_METHOD_NAME, object={
         "is_valid_date_range_result": True})
     return True
 
@@ -112,19 +108,19 @@ def is_valid_datetime_range(datetime_range: tuple) -> bool:
     Validate that the datetime range is in the format 'YYYY-MM-DD HH:MM:SS'.
     """
     IS_VALID_DATETIME_RANGE_METHOD_NAME = "is_valid_datetime_range"
-    MiniLogger.start(IS_VALID_DATETIME_RANGE_METHOD_NAME, object={
+    logger.start(IS_VALID_DATETIME_RANGE_METHOD_NAME, object={
         "datetime_range": datetime_range.__str__()})
-    if len(datetime_range) != RANGE_LENGTH:
-        MiniLogger.end(IS_VALID_DATETIME_RANGE_METHOD_NAME, object={
+    if len(datetime_range) != 2:
+        logger.end(IS_VALID_DATETIME_RANGE_METHOD_NAME, object={
             "is_valid_datetime_range_result": False, "reason": "len(datetime_range) != 2"})
         return False
 
     for datetime_obj in datetime_range:
         if not isinstance(datetime_obj, datetime):
-            MiniLogger.end(IS_VALID_DATETIME_RANGE_METHOD_NAME, object={
+            logger.end(IS_VALID_DATETIME_RANGE_METHOD_NAME, object={
                 "is_valid_datetime_range_result": False, "reason": "datetime_range contains non-datetime objects"})
             return False
-    MiniLogger.end(IS_VALID_DATETIME_RANGE_METHOD_NAME, object={
+    logger.end(IS_VALID_DATETIME_RANGE_METHOD_NAME, object={
         "is_valid_datetime_range_result": True})
     return True
 
@@ -153,26 +149,27 @@ def is_list_of_dicts(obj):
         False
     """
     IS_LIST_OF_DICTS_FUNCTION_NAME = "is_list_of_dicts"
-    MiniLogger.start(IS_LIST_OF_DICTS_FUNCTION_NAME, object={"obj": obj})
+    logger.start(IS_LIST_OF_DICTS_FUNCTION_NAME, object={"obj": obj})
     try:
         if not isinstance(obj, list):
             is_list_of_dicts_result = False
-            MiniLogger.end(IS_LIST_OF_DICTS_FUNCTION_NAME, object={
+            logger.end(IS_LIST_OF_DICTS_FUNCTION_NAME, object={
                 "is_list_of_dicts_result": is_list_of_dicts_result})
             return is_list_of_dicts_result
         for item in obj:
             if not isinstance(item, dict):
                 is_list_of_dicts_result = False
-                MiniLogger.end(IS_LIST_OF_DICTS_FUNCTION_NAME, object={
+                logger.end(IS_LIST_OF_DICTS_FUNCTION_NAME, object={
                     "is_list_of_dicts_result": is_list_of_dicts_result})
                 return is_list_of_dicts_result
         is_list_of_dicts_result = True
-        MiniLogger.end(IS_LIST_OF_DICTS_FUNCTION_NAME, object={
+        logger.end(IS_LIST_OF_DICTS_FUNCTION_NAME, object={
             "is_list_of_dicts_result": is_list_of_dicts_result})
         return is_list_of_dicts_result
-    except Exception as e:
-        MiniLogger.end(IS_LIST_OF_DICTS_FUNCTION_NAME, exception=e)
-        raise e
+    except Exception as exception:
+        logger.exception(IS_LIST_OF_DICTS_FUNCTION_NAME, exception)
+        logger.end(IS_LIST_OF_DICTS_FUNCTION_NAME)
+        raise
 
 
 def is_time_in_time_range(check_time: time, time_range: tuple) -> bool:
@@ -187,14 +184,14 @@ def is_time_in_time_range(check_time: time, time_range: tuple) -> bool:
         bool: True if the check_time is within the time range, False otherwise.
     """
     IS_TIME_IN_TIME_RANGE_METHOD_NAME = "is_time_in_time_range"
-    MiniLogger.start(IS_TIME_IN_TIME_RANGE_METHOD_NAME, object={
+    logger.start(IS_TIME_IN_TIME_RANGE_METHOD_NAME, object={
         "check_time": check_time.__str__(), "time_range": time_range.__str__()})
     if not is_valid_time_range(time_range) or not isinstance(check_time, time):
-        MiniLogger.end(IS_TIME_IN_TIME_RANGE_METHOD_NAME, object={
+        logger.end(IS_TIME_IN_TIME_RANGE_METHOD_NAME, object={
             "is_time_in_time_range_result": False})
         return False
     start_time, end_time = time_range
-    MiniLogger.end(IS_TIME_IN_TIME_RANGE_METHOD_NAME, object={
+    logger.end(IS_TIME_IN_TIME_RANGE_METHOD_NAME, object={
         "is_time_in_time_range_result": start_time <= check_time <= end_time})
     return start_time <= check_time <= end_time
 
@@ -211,15 +208,15 @@ def is_date_in_date_range(check_date: date, date_range: tuple) -> bool:
         bool: True if the check_date is within the date range, False otherwise.
     """
     IS_DATE_IN_DATE_RANGE_METHOD_NAME = "is_date_in_date_range"
-    MiniLogger.start(IS_DATE_IN_DATE_RANGE_METHOD_NAME, object={
+    logger.start(IS_DATE_IN_DATE_RANGE_METHOD_NAME, object={
         "check_date": check_date.__str__(), "date_range": date_range.__str__()})
     if not is_valid_date_range(date_range) or not isinstance(check_date, date):
-        MiniLogger.end(IS_DATE_IN_DATE_RANGE_METHOD_NAME, object={
+        logger.end(IS_DATE_IN_DATE_RANGE_METHOD_NAME, object={
             "is_date_in_date_range_result": False})
         return False
 
     start_date, end_date = date_range
-    MiniLogger.end(IS_DATE_IN_DATE_RANGE_METHOD_NAME, object={
+    logger.end(IS_DATE_IN_DATE_RANGE_METHOD_NAME, object={
         "is_date_in_date_range_result": start_date <= check_date <= end_date})
     return start_date <= check_date <= end_date
 
@@ -236,15 +233,15 @@ def is_datetime_in_datetime_range(check_datetime: datetime, datetime_range: tupl
         bool: True if the check_datetime is within the datetime range, False otherwise.
     """
     IS_DATETIME_IN_DATETIME_RANGE_METHOD_NAME = "is_datetime_in_datetime_range"
-    MiniLogger.start(IS_DATETIME_IN_DATETIME_RANGE_METHOD_NAME)
+    logger.start(IS_DATETIME_IN_DATETIME_RANGE_METHOD_NAME)
     if not is_valid_datetime_range(datetime_range) or not isinstance(check_datetime, datetime):
-        MiniLogger.end(IS_DATETIME_IN_DATETIME_RANGE_METHOD_NAME, object={
+        logger.end(IS_DATETIME_IN_DATETIME_RANGE_METHOD_NAME, object={
             "is_valid_datetime_range": False})
         return False
 
     start_datetime, end_datetime = datetime_range
     is_datetime_in_datetime_range_result = start_datetime <= check_datetime <= end_datetime
-    MiniLogger.end(IS_DATETIME_IN_DATETIME_RANGE_METHOD_NAME, object={
+    logger.end(IS_DATETIME_IN_DATETIME_RANGE_METHOD_NAME, object={
         "is_datetime_in_datetime_range_result": is_datetime_in_datetime_range_result})
     return is_datetime_in_datetime_range_result
 
@@ -277,13 +274,13 @@ def create_http_body(body):
 
 
 def get_brand_name():
-    validate_brand_name()
-    return BRAND_NAME
+    return our_get_env("BRAND_NAME")
 
 
 def get_environment_name():
-    validate_environment_name()
-    return ENVIRONMENT_NAME
+    environment_name = our_get_env("ENVIRONMENT_NAME")
+    EnvironmentName(environment_name)  # if invalid, raises ValueError: x is not a valid EnvironmentName
+    return environment_name
 
 
 def our_get_env(key: str, default: str = None, raise_if_not_found: bool = True) -> str:
@@ -302,4 +299,4 @@ def get_sql_username() -> str:
 
 
 def get_sql_password() -> str:
-    return our_get_env("RDS_PASSWORD")
\ No newline at end of file
+    return our_get_env("RDS_PASSWORD")
